@@ -39,26 +39,29 @@
 /* ==== PLATFORM handles OS, operating environment, graphics API, and
    CPU. This macro will be phased out in favor of platform adaptation
    macros, policy decision macros, and top-level port definitions. ==== */
-#define PLATFORM(WTF_FEATURE) WTF_PLATFORM_##WTF_FEATURE
+#define PLATFORM(WTF_FEATURE) (defined WTF_PLATFORM_##WTF_FEATURE && WTF_PLATFORM_##WTF_FEATURE)
 
 
 /* ==== Platform adaptation macros: these describe properties of the target environment. ==== */
 
 /* CPU() - the target CPU architecture */
-#define CPU(WTF_FEATURE) WTF_CPU_##WTF_FEATURE
+#ifdef Q_OS_VXWORKS
+#undef CPU
+#endif // Q_OS_VXWORKS
+#define CPU(WTF_FEATURE) (defined WTF_CPU_##WTF_FEATURE && WTF_CPU_##WTF_FEATURE)
 /* HAVE() - specific system features (headers, functions or similar) that are present or not */
-#define HAVE(WTF_FEATURE) HAVE_##WTF_FEATURE
+#define HAVE(WTF_FEATURE) (defined HAVE_##WTF_FEATURE && HAVE_##WTF_FEATURE)
 /* OS() - underlying operating system; only to be used for mandated low-level services like 
    virtual memory, not to choose a GUI toolkit */
-#define OS(WTF_FEATURE) WTF_OS_##WTF_FEATURE
+#define OS(WTF_FEATURE) (defined WTF_OS_##WTF_FEATURE && WTF_OS_##WTF_FEATURE)
 
 
 /* ==== Policy decision macros: these define policy choices for a particular port. ==== */
 
 /* USE() - use a particular third-party library or optional OS service */
-#define USE(WTF_FEATURE) WTF_USE_##WTF_FEATURE
+#define USE(WTF_FEATURE) (defined WTF_USE_##WTF_FEATURE && WTF_USE_##WTF_FEATURE)
 /* ENABLE() - turn on a specific feature of WebKit */
-#define ENABLE(WTF_FEATURE) ENABLE_##WTF_FEATURE
+#define ENABLE(WTF_FEATURE) (defined ENABLE_##WTF_FEATURE && ENABLE_##WTF_FEATURE)
 
 
 /* ==== CPU() - the target CPU architecture ==== */
@@ -443,6 +446,11 @@
 #define WTF_OS_RTEMS 1
 #endif
 
+/* OS(VXWORKS) - VXWORKS */
+#if defined(__vxworks)
+#define WTF_OS_VXWORKS 1
+#endif
+
 #define WTF_OS_WIN ERROR "USE WINDOWS WITH OS NOT WIN"
 #define WTF_OS_MAC ERROR "USE MAC_OS_X WITH OS NOT MAC"
 
@@ -458,6 +466,7 @@
     || OS(QNX)              \
     || OS(RTEMS)            \
     || OS(SOLARIS)          \
+    || OS(VXWORKS)          \
     || defined(unix)        \
     || defined(__unix)      \
     || defined(__unix__)
