@@ -1,5 +1,6 @@
 // Copyright (C) 2021 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:trusted-sources
 
 #include "qqmlcodemodel_p.h"
 #include "qqmllsplugin_p.h"
@@ -208,7 +209,9 @@ void QQmlCodeModel::openNeedUpdate()
             openUpdateStart();
     }
     QThreadPool::globalInstance()->start([this]() {
+        QScopedValueRollback thread(m_openUpdateThread, QThread::currentThread());
         while (openUpdateSome()) { }
+        emit openUpdateThreadFinished();
     });
 }
 
@@ -218,6 +221,8 @@ bool QQmlCodeModel::openUpdateSome()
     QByteArray toUpdate;
     {
         QMutexLocker l(&m_mutex);
+        Q_ASSERT(QThread::currentThread() == m_openUpdateThread);
+
         if (m_openDocumentsToUpdate.isEmpty()) {
             if (--m_nUpdateInProgress == 0)
                 openUpdateEnd();
@@ -440,6 +445,7 @@ void QQmlCodeModel::onCppFileChanged(const QString &)
 
 void QQmlCodeModel::newDocForOpenFile(const QByteArray &url, int version, const QString &docText)
 {
+    Q_ASSERT(QThread::currentThread() == m_openUpdateThread);
     qCDebug(codeModelLog) << "updating doc" << url << "to version" << version << "("
                           << docText.size() << "chars)";
 
@@ -581,7 +587,7 @@ QStringList QQmlCodeModel::importPathsForFile(const QString &fileName)
 
     const QString importPaths = u"importPaths"_s;
     if (m_settings && m_settings->search(fileName) && m_settings->isSet(importPaths)) {
-        result.append(m_settings->value(importPaths).toString().split(QDir::listSeparator()));
+        result.append(m_settings->valueAsAbsolutePathList(importPaths, fileName));
     }
 
     const QStringList buildPath = buildPathsForFileUrl(m_path2url[fileName]);
@@ -714,6 +720,7 @@ void QQmlCodeModel::openUpdate(const QByteArray &url)
     std::shared_ptr<Utils::TextDocument> document;
     {
         QMutexLocker l(&m_mutex);
+        Q_ASSERT(QThread::currentThread() == m_openUpdateThread);
         OpenDocument &doc = m_openDocuments[url];
         document = doc.textDocument;
         if (!document)
@@ -829,6 +836,7 @@ QStringList QQmllsBuildInformation::importPathsFor(const QString &filePath)
             longestMatch = matchLength;
         }
     }
+    QQmlToolingSettings::resolveRelativeImportPaths(filePath, &result);
     return result;
 }
 
