@@ -1,5 +1,6 @@
 // Copyright (C) 2018 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #include "qquickdraghandler_p.h"
 #include <private/qquickwindow_p.h>
@@ -136,6 +137,7 @@ void QQuickDragHandler::onActiveChanged()
     } else {
         m_pressTargetPos = QPointF();
         m_pressedInsideTarget = false;
+        m_pressedInsideParent = false;
         if (auto parent = parentItem()) {
             parent->setKeepTouchGrab(false);
             parent->setKeepMouseGrab(false);
@@ -159,6 +161,22 @@ bool QQuickDragHandler::wantsPointerEvent(QPointerEvent *event)
        return false;
 #endif
 
+    if (event->isBeginEvent()) {
+        // At least one point must be pressed in the parent item
+        if (event->isSinglePointEvent()) {
+            m_pressedInsideParent = parentContains(event->points().first());
+        } else {
+            for (int i = 0; !m_pressedInsideParent && i < event->pointCount(); ++i) {
+                auto &p = event->point(i);
+                if (p.state() == QEventPoint::Pressed && parentContains(p))
+                    m_pressedInsideParent = true;
+            }
+        }
+    }
+
+    if (!m_pressedInsideParent)
+        return false;
+
     return true;
 }
 
@@ -202,7 +220,11 @@ void QQuickDragHandler::handlePointerEventImpl(QPointerEvent *event)
             setPassiveGrab(event, *point);
             // Calculate drag delta, taking into account the axis enabled constraint
             // i.e. if xAxis is not enabled, then ignore the horizontal component of the actual movement
-            QVector2D accumulatedDragDelta = QVector2D(point->scenePosition() - point->scenePressPosition());
+            auto const mapFromScene = [this](auto const &scenePos) {
+                return target() ? target()->mapFromScene(scenePos) : scenePos;
+            };
+            QVector2D accumulatedDragDelta = QVector2D(mapFromScene(point->scenePosition())
+                                                       - mapFromScene(point->scenePressPosition()));
             if (!m_xAxis.enabled()) {
                 // If horizontal dragging is disallowed, but the user is dragging
                 // mostly horizontally, then don't activate.
