@@ -1,5 +1,6 @@
 // Copyright (C) 2020 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QQUICKEVENTS_P_P_H
 #define QQUICKEVENTS_P_P_H
@@ -36,7 +37,7 @@ class QPointerEvent;
 class QMouseEvent;
 class QQuickPointerHandler;
 
-class Q_QUICK_PRIVATE_EXPORT QQuickKeyEvent : public QObject
+class Q_QUICK_EXPORT QQuickKeyEvent : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(int key READ key CONSTANT FINAL)
@@ -46,7 +47,8 @@ class Q_QUICK_PRIVATE_EXPORT QQuickKeyEvent : public QObject
     Q_PROPERTY(int count READ count CONSTANT FINAL)
     Q_PROPERTY(quint32 nativeScanCode READ nativeScanCode CONSTANT FINAL)
     Q_PROPERTY(bool accepted READ isAccepted WRITE setAccepted FINAL)
-    QML_ANONYMOUS
+    QML_NAMED_ELEMENT(KeyEvent)
+    QML_UNCREATABLE("Should only be used by signal handlers in the Keys attached property")
     QML_ADDED_IN_VERSION(2, 0)
 
 public:
@@ -102,7 +104,7 @@ private:
     bool m_autoRepeat = false;
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickMouseEvent : public QObject
+class Q_QUICK_EXPORT QQuickMouseEvent : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(qreal x READ x CONSTANT FINAL)
@@ -113,11 +115,12 @@ class Q_QUICK_PRIVATE_EXPORT QQuickMouseEvent : public QObject
 #if QT_DEPRECATED_SINCE(6, 6)
     Q_PROPERTY(int source READ source CONSTANT REVISION(2, 7) FINAL)
 #endif
-    Q_PROPERTY(bool wasHeld READ wasHeld CONSTANT FINAL)
     Q_PROPERTY(bool isClick READ isClick CONSTANT FINAL)
+    Q_PROPERTY(bool wasHeld READ wasHeld CONSTANT FINAL)
     Q_PROPERTY(bool accepted READ isAccepted WRITE setAccepted FINAL)
     Q_PROPERTY(int flags READ flags CONSTANT REVISION(2, 11) FINAL)
-    QML_ANONYMOUS
+    QML_NAMED_ELEMENT(MouseEvent)
+    QML_UNCREATABLE("Should only be used by mouse event signal handlers, for example in MouseArea")
     QML_ADDED_IN_VERSION(2, 0)
 
 public:
@@ -177,7 +180,7 @@ private:
 };
 
 #if QT_CONFIG(wheelevent)
-class Q_QUICK_PRIVATE_EXPORT QQuickWheelEvent : public QObject
+class Q_QUICK_EXPORT QQuickWheelEvent : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(const QPointingDevice *device READ pointingDevice CONSTANT FINAL)
@@ -190,7 +193,8 @@ class Q_QUICK_PRIVATE_EXPORT QQuickWheelEvent : public QObject
     Q_PROPERTY(int modifiers READ modifiers CONSTANT FINAL)
     Q_PROPERTY(bool inverted READ inverted CONSTANT FINAL)
     Q_PROPERTY(bool accepted READ isAccepted WRITE setAccepted FINAL)
-    QML_ANONYMOUS
+    QML_NAMED_ELEMENT(WheelEvent)
+    QML_UNCREATABLE("Should only be used by wheel event signal handlers, for example in MouseArea")
     QML_ADDED_IN_VERSION(2, 0)
 
 public:
@@ -236,11 +240,12 @@ private:
 };
 #endif
 
-class Q_QUICK_PRIVATE_EXPORT QQuickCloseEvent : public QObject
+class Q_QUICK_EXPORT QQuickCloseEvent : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool accepted READ isAccepted WRITE setAccepted FINAL)
-    QML_ANONYMOUS
+    QML_NAMED_ELEMENT(CloseEvent)
+    QML_UNCREATABLE("Should only be used by Window's closing signal")
     QML_ADDED_IN_VERSION(2, 0)
 
 public:
@@ -255,14 +260,4 @@ private:
 
 QT_END_NAMESPACE
 
-QML_DECLARE_TYPE(QQuickKeyEvent)
-QML_DECLARE_TYPE(QQuickMouseEvent)
-#if QT_CONFIG(wheelevent)
-QML_DECLARE_TYPE(QQuickWheelEvent)
-#endif
-QML_DECLARE_TYPE(QQuickCloseEvent)
-QML_DECLARE_TYPE(QPointingDevice)
-QML_DECLARE_TYPE(QPointingDeviceUniqueId)
-QML_DECLARE_TYPE(QPointerEvent)
-
 #endif // QQUICKEVENTS_P_P_H
