@@ -1174,7 +1174,7 @@ void QSGThreadedRenderLoop::hide(QQuickWindow *window)
 
 void QSGThreadedRenderLoop::resize(QQuickWindow *window)
 {
-    qCDebug(QSG_LOG_RENDERLOOP) << "reisze()" << window;
+    qCDebug(QSG_LOG_RENDERLOOP) << "resize()" << window;
 
     Window *w = windowFor(window);
     if (!w)
