@@ -1,49 +1,16 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Copyright (C) 2016 Gunnar Sletta <gunnar@sletta.org>
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtQuick module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// Copyright (C) 2016 Gunnar Sletta <gunnar@sletta.org>
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #include "qquickanimatorcontroller_p.h"
 #include "qquickanimatorjob_p.h"
 #include "qquickanimator_p.h"
 #include "qquickanimator_p_p.h"
 #include <private/qquickitem_p.h>
+#if QT_CONFIG(quick_shadereffect)
 #include <private/qquickshadereffect_p.h>
+#endif
 #include <private/qanimationgroupjob_p.h>
 
 #include <qcoreapplication.h>
@@ -81,14 +48,14 @@ struct QQuickTransformAnimatorHelperStore
 };
 Q_GLOBAL_STATIC(QQuickTransformAnimatorHelperStore, qquick_transform_animatorjob_helper_store);
 
-QQuickAnimatorProxyJob::QQuickAnimatorProxyJob(QAbstractAnimationJob *job, QObject *item)
+QQuickAnimatorProxyJob::QQuickAnimatorProxyJob(QAbstractAnimationJob *job,
+                                               QQuickAbstractAnimation *animation)
     : m_controller(nullptr)
     , m_internalState(State_Stopped)
 {
     m_job.reset(job);
 
     m_isRenderThreadProxy = true;
-    m_animation = qobject_cast<QQuickAbstractAnimation *>(item);
 
     setLoopCount(job->loopCount());
 
@@ -101,7 +68,7 @@ QQuickAnimatorProxyJob::QQuickAnimatorProxyJob(QAbstractAnimationJob *job, QObje
     // be negligiblie compared to animating and re-rendering the scene on the render thread.
     m_duration = -1;
 
-    QObject *ctx = findAnimationContext(m_animation);
+    QObject *ctx = findAnimationContext(animation);
     if (!ctx) {
         qWarning("QtQuick: unable to find animation context for RT animation...");
         return;
@@ -243,7 +210,7 @@ static void qquick_syncback_helper(QAbstractAnimationJob *job)
 
     } else if (job->isGroup()) {
         QAnimationGroupJob *g = static_cast<QAnimationGroupJob *>(job);
-        for (QAbstractAnimationJob *a = g->firstChild(); a; a = a->nextSibling())
+        for (QAbstractAnimationJob *a : *g->children())
             qquick_syncback_helper(a);
     }
 
@@ -280,6 +247,17 @@ qreal QQuickAnimatorJob::progress(int time) const
     return m_easing.valueForProgress((m_duration == 0) ? qreal(1) : qreal(time) / qreal(m_duration));
 }
 
+void QQuickAnimatorJob::boundValue()
+{
+    qreal rangeMin = m_from;
+    qreal rangeMax = m_to;
+    if (m_from > m_to) {
+        rangeMax = m_from;
+        rangeMin = m_to;
+    }
+    m_value = qBound(rangeMin, m_value, rangeMax);
+}
+
 qreal QQuickAnimatorJob::value() const
 {
     qreal value = m_to;
@@ -383,11 +361,12 @@ void QQuickTransformAnimatorJob::Helper::sync()
         wasSynced = true;
     }
 
+    // We update the node before checking on dirty, as the node might have changed without the animator running
+    node = d->itemNode();
+
     if (dirty == 0)
         return;
 
-    node = d->itemNode();
-
     if (dirty & QQuickItemPrivate::Position) {
         dx = item->x();
         dy = item->y();
@@ -599,6 +578,7 @@ void QQuickOpacityAnimatorJob::updateCurrentTime(int time)
     m_opacityNode->setOpacity(m_value);
 }
 
+#if QT_CONFIG(quick_shadereffect)
 QQuickUniformAnimatorJob::QQuickUniformAnimatorJob()
 {
     m_isUniform = true;
@@ -613,7 +593,7 @@ void QQuickUniformAnimatorJob::setTarget(QQuickItem *target)
 
 void QQuickUniformAnimatorJob::updateCurrentTime(int time)
 {
-    if (!m_effect)
+    if (!m_effect || m_target != m_effect)
         return;
 
     m_value = m_from + (m_to - m_from) * progress(time);
@@ -638,8 +618,9 @@ void QQuickUniformAnimatorJob::postSync()
 
 void QQuickUniformAnimatorJob::invalidate()
 {
-    m_effect = nullptr;
+
 }
+#endif
 
 QT_END_NAMESPACE
 
