@@ -1,41 +1,6 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtQuick module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QQUICKVALUETYPES_P_H
 #define QQUICKVALUETYPES_P_H
@@ -66,9 +31,8 @@
 
 QT_BEGIN_NAMESPACE
 
-class Q_QUICK_PRIVATE_EXPORT QQuickColorValueType
+class Q_QUICK_EXPORT QQuickColorValueType : public QColor
 {
-    QColor v;
     Q_PROPERTY(qreal r READ r WRITE setR FINAL)
     Q_PROPERTY(qreal g READ g WRITE setG FINAL)
     Q_PROPERTY(qreal b READ b WRITE setB FINAL)
@@ -79,22 +43,26 @@ class Q_QUICK_PRIVATE_EXPORT QQuickColorValueType
     Q_PROPERTY(qreal hslHue READ hslHue WRITE setHslHue FINAL)
     Q_PROPERTY(qreal hslSaturation READ hslSaturation WRITE setHslSaturation FINAL)
     Q_PROPERTY(qreal hslLightness READ hslLightness WRITE setHslLightness FINAL)
-    Q_PROPERTY(bool valid READ isValid)
+    Q_PROPERTY(bool valid READ isValid FINAL)
     Q_GADGET
     QML_ADDED_IN_VERSION(2, 0)
     QML_FOREIGN(QColor)
     QML_VALUE_TYPE(color)
     QML_EXTENDED(QQuickColorValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
 
+    Q_INVOKABLE QQuickColorValueType() = default;
+    Q_INVOKABLE QQuickColorValueType(const QColor &color) : QColor(color) {}
+    Q_INVOKABLE QQuickColorValueType(const QString &string);
     Q_INVOKABLE QString toString() const;
 
-    Q_INVOKABLE QVariant alpha(qreal value) const;
-    Q_INVOKABLE QVariant lighter(qreal factor = 1.5) const;
-    Q_INVOKABLE QVariant darker(qreal factor = 2.0) const;
-    Q_INVOKABLE QVariant tint(QVariant factor) const;
+    Q_INVOKABLE QColor alpha(qreal value) const;
+    Q_INVOKABLE QColor lighter(qreal factor = 1.5) const;
+    Q_INVOKABLE QColor darker(qreal factor = 2.0) const;
+    Q_INVOKABLE QColor tint(const QColor &tintColor) const;
 
     qreal r() const;
     qreal g() const;
@@ -119,9 +87,8 @@ public:
     void setHslLightness(qreal);
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickVector2DValueType
+class Q_QUICK_EXPORT QQuickVector2DValueType : public QVector2D
 {
-    QVector2D v;
     Q_PROPERTY(qreal x READ x WRITE setX FINAL)
     Q_PROPERTY(qreal y READ y WRITE setY FINAL)
     Q_GADGET
@@ -129,10 +96,13 @@ class Q_QUICK_PRIVATE_EXPORT QQuickVector2DValueType
     QML_FOREIGN(QVector2D)
     QML_VALUE_TYPE(vector2d)
     QML_EXTENDED(QQuickVector2DValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
 
+    Q_INVOKABLE QQuickVector2DValueType() = default;
+    Q_INVOKABLE QQuickVector2DValueType(const QVector2D &vector2D) : QVector2D(vector2D) {}
     Q_INVOKABLE QString toString() const;
 
     qreal x() const;
@@ -153,9 +123,8 @@ public:
     Q_INVOKABLE bool fuzzyEquals(const QVector2D &vec) const;
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickVector3DValueType
+class Q_QUICK_EXPORT QQuickVector3DValueType : public QVector3D
 {
-    QVector3D v;
     Q_PROPERTY(qreal x READ x WRITE setX FINAL)
     Q_PROPERTY(qreal y READ y WRITE setY FINAL)
     Q_PROPERTY(qreal z READ z WRITE setZ FINAL)
@@ -164,10 +133,13 @@ class Q_QUICK_PRIVATE_EXPORT QQuickVector3DValueType
     QML_FOREIGN(QVector3D)
     QML_VALUE_TYPE(vector3d)
     QML_EXTENDED(QQuickVector3DValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
 
+    Q_INVOKABLE QQuickVector3DValueType() = default;
+    Q_INVOKABLE QQuickVector3DValueType(const QVector3D &vector3D) : QVector3D(vector3D) {}
     Q_INVOKABLE QString toString() const;
 
     qreal x() const;
@@ -192,9 +164,8 @@ public:
     Q_INVOKABLE bool fuzzyEquals(const QVector3D &vec) const;
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickVector4DValueType
+class Q_QUICK_EXPORT QQuickVector4DValueType : public QVector4D
 {
-    QVector4D v;
     Q_PROPERTY(qreal x READ x WRITE setX FINAL)
     Q_PROPERTY(qreal y READ y WRITE setY FINAL)
     Q_PROPERTY(qreal z READ z WRITE setZ FINAL)
@@ -204,10 +175,13 @@ class Q_QUICK_PRIVATE_EXPORT QQuickVector4DValueType
     QML_FOREIGN(QVector4D)
     QML_VALUE_TYPE(vector4d)
     QML_EXTENDED(QQuickVector4DValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
 
+    Q_INVOKABLE QQuickVector4DValueType() = default;
+    Q_INVOKABLE QQuickVector4DValueType(const QVector4D &vector4d) : QVector4D(vector4d) {}
     Q_INVOKABLE QString toString() const;
 
     qreal x() const;
@@ -233,22 +207,24 @@ public:
     Q_INVOKABLE bool fuzzyEquals(const QVector4D &vec) const;
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickQuaternionValueType
+class Q_QUICK_EXPORT QQuickQuaternionValueType : public QQuaternion
 {
-    QQuaternion v;
-    Q_PROPERTY(qreal scalar READ scalar WRITE setScalar)
-    Q_PROPERTY(qreal x READ x WRITE setX)
-    Q_PROPERTY(qreal y READ y WRITE setY)
-    Q_PROPERTY(qreal z READ z WRITE setZ)
+    Q_PROPERTY(qreal scalar READ scalar WRITE setScalar FINAL)
+    Q_PROPERTY(qreal x READ x WRITE setX FINAL)
+    Q_PROPERTY(qreal y READ y WRITE setY FINAL)
+    Q_PROPERTY(qreal z READ z WRITE setZ FINAL)
     Q_GADGET
     QML_ADDED_IN_VERSION(2, 0)
     QML_FOREIGN(QQuaternion)
     QML_VALUE_TYPE(quaternion)
     QML_EXTENDED(QQuickQuaternionValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
 
+    Q_INVOKABLE QQuickQuaternionValueType() = default;
+    Q_INVOKABLE QQuickQuaternionValueType(const QQuaternion &quat) : QQuaternion(quat) {}
     Q_INVOKABLE QString toString() const;
 
     qreal scalar() const;
@@ -259,11 +235,28 @@ public:
     void setX(qreal);
     void setY(qreal);
     void setZ(qreal);
+
+    Q_INVOKABLE qreal dotProduct(const QQuaternion &q) const;
+    Q_INVOKABLE QQuaternion times(const QQuaternion &q) const;
+    Q_INVOKABLE QVector3D times(const QVector3D &vec) const;
+    Q_INVOKABLE QQuaternion times(qreal factor) const;
+    Q_INVOKABLE QQuaternion plus(const QQuaternion &q) const;
+    Q_INVOKABLE QQuaternion minus(const QQuaternion &q) const;
+
+    Q_INVOKABLE QQuaternion normalized() const;
+    Q_INVOKABLE QQuaternion inverted() const;
+    Q_INVOKABLE QQuaternion conjugated() const;
+    Q_INVOKABLE qreal length() const;
+
+    Q_INVOKABLE QVector3D toEulerAngles() const;
+    Q_INVOKABLE QVector4D toVector4d() const;
+
+    Q_INVOKABLE bool fuzzyEquals(const QQuaternion &q, qreal epsilon) const;
+    Q_INVOKABLE bool fuzzyEquals(const QQuaternion &q) const;
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickMatrix4x4ValueType
+class Q_QUICK_EXPORT QQuickMatrix4x4ValueType : public QMatrix4x4
 {
-    QMatrix4x4 v;
     Q_PROPERTY(qreal m11 READ m11 WRITE setM11 FINAL)
     Q_PROPERTY(qreal m12 READ m12 WRITE setM12 FINAL)
     Q_PROPERTY(qreal m13 READ m13 WRITE setM13 FINAL)
@@ -285,50 +278,57 @@ class Q_QUICK_PRIVATE_EXPORT QQuickMatrix4x4ValueType
     QML_FOREIGN(QMatrix4x4)
     QML_VALUE_TYPE(matrix4x4)
     QML_EXTENDED(QQuickMatrix4x4ValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
 
-    qreal m11() const { return v(0, 0); }
-    qreal m12() const { return v(0, 1); }
-    qreal m13() const { return v(0, 2); }
-    qreal m14() const { return v(0, 3); }
-    qreal m21() const { return v(1, 0); }
-    qreal m22() const { return v(1, 1); }
-    qreal m23() const { return v(1, 2); }
-    qreal m24() const { return v(1, 3); }
-    qreal m31() const { return v(2, 0); }
-    qreal m32() const { return v(2, 1); }
-    qreal m33() const { return v(2, 2); }
-    qreal m34() const { return v(2, 3); }
-    qreal m41() const { return v(3, 0); }
-    qreal m42() const { return v(3, 1); }
-    qreal m43() const { return v(3, 2); }
-    qreal m44() const { return v(3, 3); }
+    Q_INVOKABLE QQuickMatrix4x4ValueType() = default;
 
-    void setM11(qreal value) { v(0, 0) = value; }
-    void setM12(qreal value) { v(0, 1) = value; }
-    void setM13(qreal value) { v(0, 2) = value; }
-    void setM14(qreal value) { v(0, 3) = value; }
-    void setM21(qreal value) { v(1, 0) = value; }
-    void setM22(qreal value) { v(1, 1) = value; }
-    void setM23(qreal value) { v(1, 2) = value; }
-    void setM24(qreal value) { v(1, 3) = value; }
-    void setM31(qreal value) { v(2, 0) = value; }
-    void setM32(qreal value) { v(2, 1) = value; }
-    void setM33(qreal value) { v(2, 2) = value; }
-    void setM34(qreal value) { v(2, 3) = value; }
-    void setM41(qreal value) { v(3, 0) = value; }
-    void setM42(qreal value) { v(3, 1) = value; }
-    void setM43(qreal value) { v(3, 2) = value; }
-    void setM44(qreal value) { v(3, 3) = value; }
+    qreal m11() const { return (*this)(0, 0); }
+    qreal m12() const { return (*this)(0, 1); }
+    qreal m13() const { return (*this)(0, 2); }
+    qreal m14() const { return (*this)(0, 3); }
+    qreal m21() const { return (*this)(1, 0); }
+    qreal m22() const { return (*this)(1, 1); }
+    qreal m23() const { return (*this)(1, 2); }
+    qreal m24() const { return (*this)(1, 3); }
+    qreal m31() const { return (*this)(2, 0); }
+    qreal m32() const { return (*this)(2, 1); }
+    qreal m33() const { return (*this)(2, 2); }
+    qreal m34() const { return (*this)(2, 3); }
+    qreal m41() const { return (*this)(3, 0); }
+    qreal m42() const { return (*this)(3, 1); }
+    qreal m43() const { return (*this)(3, 2); }
+    qreal m44() const { return (*this)(3, 3); }
 
-    Q_INVOKABLE void translate(const QVector3D &t) { v.translate(t); }
-    Q_INVOKABLE void rotate(float angle, const QVector3D &axis) { v.rotate(angle, axis); }
-    Q_INVOKABLE void scale(float s) { v.scale(s); }
-    Q_INVOKABLE void scale(float sx, float sy, float sz) { v.scale(sx, sy, sz); }
-    Q_INVOKABLE void scale(const QVector3D &s) { v.scale(s); }
-    Q_INVOKABLE void lookAt(const QVector3D &eye, const QVector3D &center, const QVector3D &up) { v.lookAt(eye, center, up); }
+    void setM11(qreal value) { (*this)(0, 0) = value; }
+    void setM12(qreal value) { (*this)(0, 1) = value; }
+    void setM13(qreal value) { (*this)(0, 2) = value; }
+    void setM14(qreal value) { (*this)(0, 3) = value; }
+    void setM21(qreal value) { (*this)(1, 0) = value; }
+    void setM22(qreal value) { (*this)(1, 1) = value; }
+    void setM23(qreal value) { (*this)(1, 2) = value; }
+    void setM24(qreal value) { (*this)(1, 3) = value; }
+    void setM31(qreal value) { (*this)(2, 0) = value; }
+    void setM32(qreal value) { (*this)(2, 1) = value; }
+    void setM33(qreal value) { (*this)(2, 2) = value; }
+    void setM34(qreal value) { (*this)(2, 3) = value; }
+    void setM41(qreal value) { (*this)(3, 0) = value; }
+    void setM42(qreal value) { (*this)(3, 1) = value; }
+    void setM43(qreal value) { (*this)(3, 2) = value; }
+    void setM44(qreal value) { (*this)(3, 3) = value; }
+
+    Q_INVOKABLE void translate(const QVector3D &t) { QMatrix4x4::translate(t); }
+    Q_INVOKABLE void rotate(float angle, const QVector3D &axis) { QMatrix4x4::rotate(angle, axis); }
+    Q_INVOKABLE void rotate(const QQuaternion &q) { QMatrix4x4::rotate(q); }
+    Q_INVOKABLE void scale(float s) { QMatrix4x4::scale(s); }
+    Q_INVOKABLE void scale(float sx, float sy, float sz) { QMatrix4x4::scale(sx, sy, sz); }
+    Q_INVOKABLE void scale(const QVector3D &s) { QMatrix4x4::scale(s); }
+    Q_INVOKABLE void lookAt(const QVector3D &eye, const QVector3D &center, const QVector3D &up)
+    {
+        QMatrix4x4::lookAt(eye, center, up);
+    }
 
     Q_INVOKABLE QMatrix4x4 times(const QMatrix4x4 &m) const;
     Q_INVOKABLE QVector4D times(const QVector4D &vec) const;
@@ -344,13 +344,38 @@ public:
     Q_INVOKABLE QMatrix4x4 inverted() const;
     Q_INVOKABLE QMatrix4x4 transposed() const;
 
+    Q_INVOKABLE QPointF map(const QPointF p) const;
+    Q_INVOKABLE QRectF mapRect(const QRectF r) const;
+
     Q_INVOKABLE bool fuzzyEquals(const QMatrix4x4 &m, qreal epsilon) const;
     Q_INVOKABLE bool fuzzyEquals(const QMatrix4x4 &m) const;
 };
 
+class Q_QUICK_EXPORT QQuickPlanarTransform : public QObject
+{
+    Q_OBJECT
+    QML_SINGLETON
+    QML_NAMED_ELEMENT(PlanarTransform)
+    QML_ADDED_IN_VERSION(6, 8)
+
+public:
+    explicit QQuickPlanarTransform(QObject *parent = nullptr);
+
+    Q_INVOKABLE static QMatrix4x4 identity();
+    Q_INVOKABLE static QMatrix4x4 fromAffineMatrix(float scaleX, float shearY,
+                                                   float shearX, float scaleY,
+                                                   float translateX, float translateY);
+    Q_INVOKABLE static QMatrix4x4 fromTranslate(float translateX, float translateY);
+    Q_INVOKABLE static QMatrix4x4 fromScale(float scaleX, float scaleY,
+                                            float originX = 0, float originY = 0);
+    Q_INVOKABLE static QMatrix4x4 fromRotate(float angle,float originX = 0, float originY = 0);
+    Q_INVOKABLE static QMatrix4x4 fromShear(float shearX, float shearY,
+                                            float originX = 0, float originY = 0);
+};
+
 namespace QQuickFontEnums
 {
-Q_NAMESPACE
+Q_NAMESPACE_EXPORT(Q_QUICK_EXPORT)
 
 QML_NAMED_ELEMENT(Font)
 QML_ADDED_IN_VERSION(2, 0)
@@ -379,11 +404,17 @@ enum HintingPreference {
     PreferFullHinting = QFont::PreferFullHinting
 };
 Q_ENUM_NS(HintingPreference)
+
+enum Style {
+    StyleNormal = QFont::StyleNormal,
+    StyleItalic = QFont::StyleItalic,
+    StyleOblique = QFont::StyleOblique,
+};
+Q_ENUM_NS(Style)
 };
 
-class Q_QUICK_PRIVATE_EXPORT QQuickFontValueType
+class Q_QUICK_EXPORT QQuickFontValueType : public QFont
 {
-    QFont v;
     Q_GADGET
 
     Q_PROPERTY(QString family READ family WRITE setFamily FINAL)
@@ -402,15 +433,22 @@ class Q_QUICK_PRIVATE_EXPORT QQuickFontValueType
     Q_PROPERTY(QQuickFontEnums::HintingPreference hintingPreference READ hintingPreference WRITE setHintingPreference FINAL)
     Q_PROPERTY(bool kerning READ kerning WRITE setKerning FINAL)
     Q_PROPERTY(bool preferShaping READ preferShaping WRITE setPreferShaping FINAL)
+    Q_PROPERTY(QVariantMap features READ features WRITE setFeatures FINAL)
+    Q_PROPERTY(QVariantMap variableAxes READ variableAxes WRITE setVariableAxes FINAL)
+    Q_PROPERTY(bool contextFontMerging READ contextFontMerging WRITE setContextFontMerging FINAL)
+    Q_PROPERTY(bool preferTypoLineMetrics READ preferTypoLineMetrics WRITE setPreferTypoLineMetrics FINAL)
 
     QML_VALUE_TYPE(font)
     QML_FOREIGN(QFont)
     QML_ADDED_IN_VERSION(2, 0)
     QML_EXTENDED(QQuickFontValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &value);
 
+    Q_INVOKABLE QQuickFontValueType() = default;
+    Q_INVOKABLE QQuickFontValueType(const QFont &font) : QFont(font) {}
     Q_INVOKABLE QString toString() const;
 
     QString family() const;
@@ -460,11 +498,23 @@ public:
 
     bool preferShaping() const;
     void setPreferShaping(bool b);
+
+    QVariantMap features() const;
+    void setFeatures(const QVariantMap &features);
+
+    QVariantMap variableAxes() const;
+    void setVariableAxes(const QVariantMap &variableAxes);
+
+    bool contextFontMerging() const;
+    void setContextFontMerging(bool b);
+
+    bool preferTypoLineMetrics() const;
+    void setPreferTypoLineMetrics(bool b);
 };
 
 namespace QQuickColorSpaceEnums
 {
-Q_NAMESPACE
+Q_NAMESPACE_EXPORT(Q_QUICK_EXPORT)
 QML_NAMED_ELEMENT(ColorSpace)
 QML_ADDED_IN_VERSION(2, 15)
 Q_CLASSINFO("RegisterEnumClassesUnscoped", "false")
@@ -497,9 +547,8 @@ enum class TransferFunction {
 Q_ENUM_NS(TransferFunction)
 }
 
-class Q_QUICK_PRIVATE_EXPORT QQuickColorSpaceValueType
+class Q_QUICK_EXPORT QQuickColorSpaceValueType : public QColorSpace
 {
-    QColorSpace v;
     Q_GADGET
 
     Q_PROPERTY(QQuickColorSpaceEnums::NamedColorSpace namedColorSpace READ namedColorSpace WRITE setNamedColorSpace FINAL)
@@ -511,6 +560,7 @@ class Q_QUICK_PRIVATE_EXPORT QQuickColorSpaceValueType
     QML_FOREIGN(QColorSpace)
     QML_ADDED_IN_VERSION(2, 15)
     QML_EXTENDED(QQuickColorSpaceValueType)
+    QML_STRUCTURED_VALUE
 
 public:
     static QVariant create(const QJSValue &params);
