@@ -55,6 +55,7 @@ QT_BEGIN_NAMESPACE
     and let the button box setup the buttons.
 
     \image qtquickcontrols-dialogbuttonbox.png
+           {Dialog button box with OK and Cancel buttons}
 
     \snippet qtquickcontrols-dialogbuttonbox.qml 1
 
@@ -776,7 +777,7 @@ void QQuickDialogButtonBox::itemRemoved(int index, QQuickItem *item)
 #if QT_CONFIG(accessibility)
 QAccessible::Role QQuickDialogButtonBox::accessibleRole() const
 {
-    return QAccessible::PageTabList;
+    return QAccessible::Grouping;
 }
 #endif
 
