@@ -3,10 +3,10 @@
 
 /*---
 esid: sec-array.prototype.foreach
-es5id: 15.4.4.18-7-b-14
+es5id: 15.4.4.18-7-b-3
 description: >
-    Array.prototype.forEach - decreasing length of array causes index
-    property not to be visited
+    Array.prototype.forEach - deleted properties in step 2 are visible
+    here
 ---*/
 
 var accessed = false;
@@ -14,22 +14,24 @@ var testResult = true;
 
 function callbackfn(val, idx, obj) {
   accessed = true;
-  if (idx === 3) {
+  if (idx === 8) {
     testResult = false;
   }
 }
+var obj = {
+  2: 6.99,
+  8: 19
+};
 
-var arr = [0, 1, 2, "last"];
-
-Object.defineProperty(arr, "0", {
+Object.defineProperty(obj, "length", {
   get: function() {
-    arr.length = 3;
-    return 0;
+    delete obj[8];
+    return 10;
   },
   configurable: true
 });
 
-arr.forEach(callbackfn);
+Array.prototype.forEach.call(obj, callbackfn);
 
 assert(testResult, 'testResult !== true');
 assert(accessed, 'accessed !== true');
