@@ -7,7 +7,7 @@ description: >
     The left-hand side expression is evaluated before the right-hand side.
     Left-hand side expression is MemberExpression: base[prop]. base is the
     undefined value.
-    Check operator is "x &= y".
+    Check operator is "x >>= y".
 ---*/
 
 function DummyError() { }
@@ -21,7 +21,7 @@ assert.throws(DummyError, function() {
     $ERROR("right-hand side expression evaluated");
   };
 
-  base[prop()] &= expr();
+  base[prop()] >>= expr();
 });
 
 assert.throws(TypeError, function() {
@@ -35,5 +35,5 @@ assert.throws(TypeError, function() {
     $ERROR("right-hand side expression evaluated");
   };
 
-  base[prop] &= expr();
+  base[prop] >>= expr();
 });
