@@ -2,16 +2,17 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 10.4.3-1-35-s
+es5id: 10.4.3-1-29-s
 description: >
     Strict Mode - checking 'this' (Anonymous FunctionExpression
-    defined within an Anonymous FunctionExpression inside strict mode)
+    defined within a FunctionDeclaration inside strict mode)
 flags: [onlyStrict]
 ---*/
 
-(function () {
-    assert.sameValue((function () {
+function f1() {
+    return ((function () {
         return typeof this;
-    })(), "undefined");
-    assert.sameValue(typeof this, "undefined", 'typeof this');
-})();
+    })()==="undefined") && ((typeof this)==="undefined");
+}
+
+assert(f1(), 'f1() !== true');
