@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <qstandardpaths.h>
 #include <qtest.h>
@@ -53,6 +53,9 @@ private slots:
     void revertValueTypeAnimation();
 
     void clearPropertyCaches();
+    void builtins();
+
+    void renameMetaType();
 };
 
 class TestType : public QObject
@@ -385,7 +388,7 @@ public:
         ENUM_VALUE_1 = 1,
         ENUM_VALUE_2 = 2
     };
-    Q_ENUMS(Controller1Enum)
+    Q_ENUM(Controller1Enum)
 
     Controller1(QObject *parent = nullptr) : QObject(parent), m_string("Controller #1"),
         m_enumVal(ENUM_VALUE_1)
@@ -405,7 +408,7 @@ public:
         ENUM_VALUE_1 = 111,
         ENUM_VALUE_2 = 222
     };
-    Q_ENUMS(Controller2Enum)
+    Q_ENUM(Controller2Enum)
 
     Controller2(QObject *parent = nullptr) : QObject(parent), m_string("Controller #2"),
         m_enumVal(ENUM_VALUE_1)
@@ -580,11 +583,11 @@ void tst_qqmlmetatype::normalizeUrls()
     const QUrl url("qrc:///tstqqmlmetatype/data/CompositeType.qml");
     QVERIFY(!QQmlMetaType::qmlType(url).isValid());
     const auto registrationId = qmlRegisterType(url, "Test", 1, 0, "ResourceCompositeType");
-    QVERIFY(QQmlMetaType::qmlType(url, /*includeNonFileImports=*/true).isValid());
+    QVERIFY(QQmlMetaType::qmlType(url).isValid());
     QUrl normalizedURL("qrc:/tstqqmlmetatype/data/CompositeType.qml");
-    QVERIFY(QQmlMetaType::qmlType(normalizedURL, /*includeNonFileImports=*/true).isValid());
+    QVERIFY(QQmlMetaType::qmlType(normalizedURL).isValid());
     QQmlMetaType::unregisterType(registrationId);
-    QVERIFY(!QQmlMetaType::qmlType(url, /*includeNonFileImports=*/true).isValid());
+    QVERIFY(!QQmlMetaType::qmlType(url).isValid());
 }
 
 void tst_qqmlmetatype::unregisterAttachedProperties()
@@ -671,9 +674,13 @@ void tst_qqmlmetatype::revisionedGroupedProperties()
     }
 
     {
+        // This is _not_ invalid. The grouped property is clearly qualified and so the
+        // version shall be ignored. It's the same as retrieving a versioned property from an
+        // object identified by ID, for example.
+
         QQmlEngine engine;
-        QQmlComponent invalid(&engine, testFileUrl("revisionedGroupedPropertiesInvalid.qml"));
-        QVERIFY(invalid.isError());
+        QQmlComponent valid2(&engine, testFileUrl("revisionedGroupedPropertiesValid2.qml"));
+        QVERIFY2(!valid2.isError(), qPrintable(valid2.errorString()));
     }
 
     {
@@ -738,6 +745,152 @@ void tst_qqmlmetatype::clearPropertyCaches()
     QVERIFY(oldCache.data() != newCache.data());
 }
 
+template<typename T>
+void checkBuiltinBaseType()
+{
+    const QQmlType type = QQmlMetaType::qmlType(QMetaType::fromType<T>());
+    QVERIFY(type.isValid());
+    QCOMPARE(type.typeId(), QMetaType::fromType<T>());
+    QCOMPARE(type.qListTypeId(), QMetaType::fromType<QList<T>>());
+}
+
+template<typename T>
+void checkBuiltinListType()
+{
+    const QQmlType listType = QQmlMetaType::qmlListType(QMetaType::fromType<QList<T>>());
+    QVERIFY(listType.isValid());
+    QVERIFY(listType.isSequentialContainer());
+    QCOMPARE(listType.typeId(), QMetaType::fromType<T>());
+    QCOMPARE(listType.qListTypeId(), QMetaType::fromType<QList<T>>());
+    QCOMPARE(listType.listMetaSequence().valueMetaType(), QMetaType::fromType<T>());
+}
+
+template<typename... T>
+void checkBuiltinTypes()
+{
+    (checkBuiltinBaseType<T>(), ...);
+    (checkBuiltinListType<T>(), ...);
+}
+
+template<typename T>
+void checkNamedBuiltin(const QString &name)
+{
+    const QQmlType expected = QQmlMetaType::qmlType(QMetaType::fromType<T>());
+    const QQmlType actual = QQmlMetaType::qmlType("QML/" + name, QTypeRevision::fromVersion(1, 0));
+    if (actual != expected) {
+        qWarning() << Q_FUNC_INFO << "looking for" << name;
+        qWarning() << "found" << actual.module() << actual.elementName() << actual.version()
+                   << actual.typeId();
+        qWarning() << "expected" << expected.module() << expected.elementName()
+                   << expected.version() << expected.typeId();
+        QFAIL("mismatch");
+    }
+}
+
+template<typename T>
+void checkObjectBuiltin(const QString &name)
+{
+    const QQmlType objectType = QQmlMetaType::qmlType(QMetaType::fromType<T *>());
+    QVERIFY(objectType.isValid());
+    QCOMPARE(objectType.typeId(), QMetaType::fromType<T *>());
+    QCOMPARE(objectType.qListTypeId(), QMetaType::fromType<QQmlListProperty<T>>());
+
+    const QQmlType listType = QQmlMetaType::qmlListType(QMetaType::fromType<QQmlListProperty<T>>());
+    QVERIFY(listType.isValid());
+    QCOMPARE(listType.typeId(), QMetaType::fromType<T *>());
+    QCOMPARE(listType.qListTypeId(), QMetaType::fromType<QQmlListProperty<T>>());
+
+    checkNamedBuiltin<T *>(name);
+}
+
+void tst_qqmlmetatype::builtins()
+{
+    qmlClearTypeRegistrations();
+    QQmlEngine engine; // registers the builtins
+
+    checkBuiltinTypes<
+        QVariant, QJSValue, qint8, quint8, short, ushort, int, uint, qlonglong, qulonglong, float,
+        double, QChar, QString, bool, QDateTime, QDate, QTime, QUrl, QByteArray>();
+
+    checkNamedBuiltin<QVariant>("var");
+    checkNamedBuiltin<QVariant>("variant");
+    checkNamedBuiltin<int>("int");
+    checkNamedBuiltin<double>("double");
+    checkNamedBuiltin<double>("real");
+    checkNamedBuiltin<QString>("string");
+    checkNamedBuiltin<bool>("bool");
+    checkNamedBuiltin<QDateTime>("date");
+    checkNamedBuiltin<QUrl>("url");
+
+#if QT_CONFIG(regularexpression)
+    checkBuiltinBaseType<QRegularExpression>();
+    checkBuiltinListType<QRegularExpression>();
+    checkNamedBuiltin<QRegularExpression>("regexp");
+#endif
+
+    // Can't retrieve this one by metatype
+    const QQmlType voidType = QQmlMetaType::qmlType("QML/void", QTypeRevision::fromVersion(1, 0));
+    QVERIFY(voidType.isValid());
+    QCOMPARE(voidType.typeId(), QMetaType());
+    QCOMPARE(voidType.qListTypeId(), QMetaType());
+
+    // No separate list types
+    checkBuiltinBaseType<std::nullptr_t>();
+    checkBuiltinBaseType<QVariantMap>();
+
+    checkObjectBuiltin<QObject>("QtObject");
+    checkObjectBuiltin<QQmlComponent>("Component");
+}
+
+void tst_qqmlmetatype::renameMetaType()
+{
+    QByteArray metaTypeName;
+    QMetaType metaType;
+
+    {
+        QQmlEngine engine;
+        QQmlComponent c(&engine, testFileUrl("testRenameMetaType.qml"));
+        QScopedPointer<QObject> obj(c.create());
+        QVERIFY(obj.data());
+        QVariant stringVal = obj->property("text");
+        QCOMPARE(stringVal.typeId(), QMetaType::QString);
+        QCOMPARE(stringVal.toString(), QStringLiteral("yes"));
+        const QQmlData *ddata = QQmlData::get(obj.data());
+        QVERIFY(ddata->compilationUnit);
+
+        metaType =  ddata->compilationUnit->baseCompilationUnit()->qmlType.typeId();
+        QVERIFY(metaType.isValid());
+        metaTypeName = metaType.name();
+        QVERIFY(!metaTypeName.isEmpty());
+    }
+    {
+        QQmlEngine engine;
+        QQmlComponent c(&engine, testFileUrl("testRenameMetaType.qml"));
+        QScopedPointer<QObject> obj(c.create());
+        QVERIFY(obj.data());
+        QVariant stringVal = obj->property("text");
+        QCOMPARE(stringVal.typeId(), QMetaType::QString);
+        QCOMPARE(stringVal.toString(), QStringLiteral("yes"));
+        const QQmlData *ddata = QQmlData::get(obj.data());
+        QVERIFY(ddata->compilationUnit);
+
+        const QMetaType newType = ddata->compilationUnit->baseCompilationUnit()->qmlType.typeId();
+        QVERIFY(newType.isValid());
+        const QByteArray newTypeName = newType.name();
+        QVERIFY(!newTypeName.isEmpty());
+
+        // The type is still the same
+        QCOMPARE(newType, metaType);
+
+        // But the name is different
+        QCOMPARE_NE(newTypeName, metaTypeName);
+
+        // The QMetaType registry has been updated
+        QCOMPARE(QMetaType::fromName(newTypeName), metaType);
+        QVERIFY(!QMetaType::fromName(metaTypeName).isValid());
+    }
+}
+
 QTEST_MAIN(tst_qqmlmetatype)
 
 #include "tst_qqmlmetatype.moc"
