@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the test suite of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <qtest.h>
 #include <private/qqmlpropertycache_p.h>
@@ -33,6 +8,7 @@
 #include <QtQml/qqmlcomponent.h>
 #include <private/qmetaobjectbuilder_p.h>
 #include <private/qqmlcontextdata_p.h>
+#include <private/qqmlpropertycachecreator_p.h>
 #include <QCryptographicHash>
 #include <QtQuickTestUtils/private/qmlutils_p.h>
 
@@ -59,6 +35,8 @@ private slots:
     void derivedGadgetMethod();
     void restrictRegistrationVersion();
     void rejectOverriddenFinal();
+    void overriddenSignals();
+    void duplicateIdsAndGeneralizedGroupProperties();
 
 private:
     QQmlEngine engine;
@@ -189,7 +167,20 @@ Q_SIGNALS:
     void signalB();
 };
 
-QQmlPropertyData *cacheProperty(const QQmlRefPointer<QQmlPropertyCache> &cache, const char *name)
+class OverriddenSignal : public BaseObject
+{
+    Q_OBJECT
+public:
+    OverriddenSignal(QObject *parent = nullptr) : BaseObject(parent) {}
+
+    Q_INVOKABLE void propertyAChanged() {  ++propertyAChangedCalled; }
+    int propertyAChangedCalled = 0;
+
+Q_SIGNALS:
+    void signalA();
+};
+
+const QQmlPropertyData *cacheProperty(const QQmlPropertyCache::ConstPtr &cache, const char *name)
 {
     return cache->property(QLatin1String(name), nullptr, nullptr);
 }
@@ -200,7 +191,7 @@ void tst_qqmlpropertycache::properties()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> cache = QQmlPropertyCache::createStandalone(metaObject);
+    QQmlPropertyCache::ConstPtr cache = QQmlPropertyCache::createStandalone(metaObject);
     const QQmlPropertyData *data;
 
     QVERIFY((data = cacheProperty(cache, "propertyA")));
@@ -222,9 +213,9 @@ void tst_qqmlpropertycache::propertiesDerived()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> parentCache
+    QQmlPropertyCache::ConstPtr parentCache
             = QQmlPropertyCache::createStandalone(&BaseObject::staticMetaObject);
-    QQmlRefPointer<QQmlPropertyCache> cache
+    QQmlPropertyCache::ConstPtr cache
             = parentCache->copyAndAppend(object.metaObject(), QTypeRevision());
     const QQmlPropertyData *data;
 
@@ -249,12 +240,12 @@ void tst_qqmlpropertycache::revisionedProperties()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> cacheWithoutVersion(
+    QQmlPropertyCache::ConstPtr cacheWithoutVersion(
                 QQmlPropertyCache::createStandalone(metaObject));
-    QQmlRefPointer<QQmlPropertyCache> cacheWithVersion(
+    QQmlPropertyCache::ConstPtr cacheWithVersion(
                 QQmlPropertyCache::createStandalone(
                     metaObject, QTypeRevision::fromMinorVersion(1)));
-    QQmlPropertyData *data;
+    const QQmlPropertyData *data;
 
     QVERIFY((data = cacheProperty(cacheWithoutVersion, "propertyE")));
     QCOMPARE(cacheWithoutVersion->isAllowedInRevision(data), false);
@@ -267,7 +258,7 @@ void tst_qqmlpropertycache::methods()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> cache(QQmlPropertyCache::createStandalone(metaObject));
+    QQmlPropertyCache::ConstPtr cache(QQmlPropertyCache::createStandalone(metaObject));
     const QQmlPropertyData *data;
 
     QVERIFY((data = cacheProperty(cache, "slotA")));
@@ -301,11 +292,11 @@ void tst_qqmlpropertycache::methodsDerived()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> parentCache(
+    QQmlPropertyCache::ConstPtr parentCache(
                 QQmlPropertyCache::createStandalone(&BaseObject::staticMetaObject));
-    QQmlRefPointer<QQmlPropertyCache> cache
+    QQmlPropertyCache::ConstPtr cache
             = parentCache->copyAndAppend(object.metaObject(), QTypeRevision {});
-    QQmlPropertyData *data;
+    const QQmlPropertyData *data;
 
     QVERIFY((data = cacheProperty(cache, "slotA")));
     QCOMPARE(data->coreIndex(), metaObject->indexOfMethod("slotA()"));
@@ -338,7 +329,7 @@ void tst_qqmlpropertycache::signalHandlers()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> cache(QQmlPropertyCache::createStandalone(metaObject));
+    QQmlPropertyCache::ConstPtr cache(QQmlPropertyCache::createStandalone(metaObject));
     const QQmlPropertyData *data;
 
     QVERIFY((data = cacheProperty(cache, "onSignalA")));
@@ -366,11 +357,11 @@ void tst_qqmlpropertycache::signalHandlersDerived()
     DerivedObject object;
     const QMetaObject *metaObject = object.metaObject();
 
-    QQmlRefPointer<QQmlPropertyCache> parentCache(
+    QQmlPropertyCache::ConstPtr parentCache(
                 QQmlPropertyCache::createStandalone(&BaseObject::staticMetaObject));
-    QQmlRefPointer<QQmlPropertyCache> cache
+    QQmlPropertyCache::ConstPtr cache
             = parentCache->copyAndAppend(object.metaObject(), QTypeRevision{});
-    QQmlPropertyData *data;
+    const QQmlPropertyData *data;
 
     QVERIFY((data = cacheProperty(cache, "onSignalA")));
     QCOMPARE(data->coreIndex(), metaObject->indexOfMethod("signalA()"));
@@ -569,9 +560,6 @@ class TestClassWithClassInfo : public QObject
 
 #include "tst_qqmlpropertycache.moc"
 
-#define ARRAY_SIZE(arr) \
-    int(sizeof(arr) / sizeof(arr[0]))
-
 template <typename T, typename = void>
 struct SizeofOffsetsAndSizes_helper
 {
@@ -590,10 +578,13 @@ constexpr size_t sizeofOffsetsAndSizes(const T &)
     return SizeofOffsetsAndSizes_helper<T>::value;
 }
 
-#define TEST_CLASS(Class) \
+// NOTE: ScopeCounter might change new metaobjects are added
+// check the moc file and adjust as necessary if tests fails to compile
+#define TEST_CLASS(Class, Fields, Strings) \
     QTest::newRow(#Class) \
-            << &Class::staticMetaObject << ARRAY_SIZE(qt_meta_data_##Class) \
-            << int(sizeofOffsetsAndSizes(qt_meta_stringdata_##Class) / (sizeof(uint) * 2))
+            << &Class::staticMetaObject \
+            << Fields \
+            << Strings
 
 Q_DECLARE_METATYPE(const QMetaObject*);
 
@@ -603,9 +594,9 @@ void tst_qqmlpropertycache::metaObjectSize_data()
     QTest::addColumn<int>("expectedFieldCount");
     QTest::addColumn<int>("expectedStringCount");
 
-    TEST_CLASS(TestClass);
-    TEST_CLASS(TestClassWithParameters);
-    TEST_CLASS(TestClassWithClassInfo);
+    TEST_CLASS(TestClass, 49, 10);
+    TEST_CLASS(TestClassWithParameters, 24, 4);
+    TEST_CLASS(TestClassWithClassInfo, 17, 3);
 }
 
 void tst_qqmlpropertycache::metaObjectSize()
@@ -732,4 +723,70 @@ void tst_qqmlpropertycache::rejectOverriddenFinal()
     QCOMPARE(o->property("c").toInt(), 0);
 }
 
+void tst_qqmlpropertycache::overriddenSignals()
+{
+    qmlRegisterTypesAndRevisions<BaseObject>("Test.PropertyCache", 3);
+    QQmlEngine engine;
+
+    QQmlComponent c1(&engine, testFileUrl("overriddenSignal.qml"));
+    QVERIFY2(!c1.isError(), qPrintable(c1.errorString()));
+
+    QScopedPointer<QObject> o(c1.create());
+
+    // the propertyAChanged _signal_ is sent once (initially).
+    QCOMPARE(o->property("a").toInt(), 1);
+
+    // signalA() is invoked once as signal, and the other time as method since both are C++.
+    QCOMPARE(o->property("b").toInt(), 1);
+
+    OverriddenSignal *derived = new OverriddenSignal(o.data());
+
+    // Does call our overridden method, since that is defined in C++
+    QCOMPARE(derived->propertyAChangedCalled, 0);
+    o->setProperty("obj", QVariant::fromValue(derived));
+    QCOMPARE(derived->propertyAChangedCalled, 1);
+
+    o->setProperty("obj2", QVariant::fromValue(derived));
+
+    // the propertyAChanged _signal_ is sent once (initially).
+    QCOMPARE(o->property("a").toInt(), 1);
+
+    // We get to receive both signalA() signals since we only match by name.
+    QCOMPARE(o->property("b").toInt(), 2);
+
+    // We shouldn't be allowed to define such things in QML, though.
+
+    const QUrl c2Url = testFileUrl("qmlOverriddenSignal.qml");
+    QTest::ignoreMessage(
+            QtWarningMsg,
+            qPrintable(c2Url.toString() + QLatin1String(
+                            ":6:14: Duplicate method name: "
+                            "invalid override of property change signal or superclass signal")));
+    QQmlComponent c2(&engine, c2Url);
+    // Should be an error, but we can't enforce it yet.
+
+    const QUrl c3Url = testFileUrl("qmlOverriddenSignal2.qml");
+    QTest::ignoreMessage(
+            QtWarningMsg,
+            qPrintable(c3Url.toString() + QLatin1String(
+                            ":5:12: Duplicate signal name: "
+                            "invalid override of property change signal or superclass signal")));
+    QQmlComponent c3(&engine, c3Url);
+    // Should be an error, but we can't enforce it yet.
+}
+
+void tst_qqmlpropertycache::duplicateIdsAndGeneralizedGroupProperties()
+{
+    QQmlEngine engine;
+    QQmlComponent c(&engine, testFileUrl("duplicateIdsAndGeneralizedGroupProperties.qml"));
+    QVERIFY2(c.isReady(), qPrintable(c.errorString()));
+
+    QTest::ignoreMessage(QtDebugMsg, "1 true true true");
+    QTest::ignoreMessage(QtDebugMsg, "2 false true true");
+    QTest::ignoreMessage(QtDebugMsg, "3 false false true");
+    QTest::ignoreMessage(QtDebugMsg, "4 false false false");
+
+    QScopedPointer<QObject> o(c.create());
+}
+
 QTEST_MAIN(tst_qqmlpropertycache)
